flutter_discord_rpc library

Classes

FlutterDiscordRPC
I32Array2
RPCActivity
A struct representing a Discord rich presence activity Note that all methods return Self, and can be chained for fluency
RPCAssets
A struct representing the art assets and hover text used by an RPCActivity Note that all methods return Self, and can be chained for fluency
RPCButton
A struct representing the buttons that are attached to an RPCActivity
RPCParty
A struct representing an RPCActivity's game party Note that all methods return Self, and can be chained for fluency
RPCSecrets
A struct representing the secrets used by an RPCActivity Note that all methods return Self, and can be chained for fluency
RPCTimestamps
A struct representing an RPCActivity's timestamps Note that all methods return Self, and can be chained for fluency

Enums

ActivityType
An enum representing the activity type used by an RPCActivity